Rails.application.configure do
	# Settings specified here will take precedence over those in config/application.rb.

	# Code is not reloaded between requests.
	config.cache_classes = true
	config.allow_concurrency = true

	# Eager load code on boot. This eager loads most of Rails and
	# your application in memory, allowing both threaded web servers
	# and those relying on copy on write to perform better.
	# Rake tasks automatically ignore this option for performance.
	config.eager_load = true

	# Full error reports are disabled and caching is turned on.
	config.consider_all_requests_local = false
	config.action_controller.perform_caching = true

	# Ensures that a master key has been made available in either ENV["RAILS_MASTER_KEY"]
	# or in config/master.key. This key is used to decrypt credentials (and other encrypted files).
	# config.require_master_key = true

	# Disable serving static files from the `/public` folder by default since
	# Apache or NGINX already handles this.
	config.public_file_server.enabled = true

	# Generate digests for assets URLs
	config.assets.digest = true

	# Compress JavaScripts and CSS
	config.assets.compress = true

	# Enable serving of images, stylesheets, and JavaScripts from an asset server.
	# config.action_controller.asset_host = 'http://assets.example.com'

	# Specifies the header that your server uses for sending files.
	# config.action_dispatch.x_sendfile_header = 'X-Sendfile' # for Apache
	# config.action_dispatch.x_sendfile_header = 'X-Accel-Redirect' # for NGINX

	# Store uploaded files on the local file system (see config/storage.yml for options)
	config.active_storage.service = :local

	# Mount Action Cable outside main process or domain
	# config.action_cable.mount_path = nil
	# config.action_cable.url = 'wss://example.com/cable'
	# config.action_cable.allowed_request_origins = [ 'http://example.com', /http:\/\/example.*/ ]

	# Force all access to the app over SSL, use Strict-Transport-Security, and use secure cookies.
	# config.force_ssl = true

	# Use the lowest log level to ensure availability of diagnostic information
	# when problems arise.
	config.log_level = :debug

	# Prepend all log lines with the following tags.
	config.log_tags = [:request_id]

	# Use a different cache store in production.
	# config.cache_store = :mem_cache_store

	# Use a real queuing backend for Active Job (and separate queues per environment)
	# config.active_job.queue_adapter     = :resque
	# config.active_job.queue_name_prefix = "RS_Server_#{Rails.env}"

	# Ignore bad email addresses and do not raise email delivery errors.
	# Set this to true and configure the email server for immediate delivery to raise delivery errors.
	# config.action_mailer.raise_delivery_errors = false
	ActionMailer::Base.smtp_settings = {
		:user_name => ENV['SENDGRID_USERNAME'],
		:password => ENV['SENDGRID_PASSWORD'],
		:domain => ENV['SENGRID_DOMAIN'],
		:address => 'smtp.sendgrid.net',
		:port => 587,
		:authentication => :plain,
		:enable_starttls_auto => true
	}
	config.action_mailer.perform_deliveries = true
	config.action_mailer.perform_caching = true

	# Enable locale fallbacks for I18n (makes lookups for any locale fall back to
	# the I18n.default_locale when a translation cannot be found).
	config.i18n.fallbacks = true

	# Send deprecation notices to registered listeners.
	config.active_support.deprecation = :notify

	# Use default logging formatter so that PID and timestamp are not suppressed.
	config.log_formatter = ::Logger::Formatter.new

	# Use a different logger for distributed setups.
	# require 'syslog/logger'
	# config.logger = ActiveSupport::TaggedLogging.new(Syslog::Logger.new 'app-name')

	if ENV["RAILS_LOG_TO_STDOUT"].present?
		logger = ActiveSupport::Logger.new(STDOUT)
		logger.formatter = config.log_formatter
		config.logger = ActiveSupport::TaggedLogging.new(logger)
	end

	# Do not dump schema after migrations.
	config.active_record.dump_schema_after_migration = false

	config.secret_key_base = ENV["SECRET_PROD_KEY"]
end
